@@ -144,6 +144,7 @@ class Dictabase:
 
 
 class BaseTable(dict):
+
     def __init__(self, *a, **k):
         self.db = k.pop('db')
         self.app = k.pop('app')
@@ -198,6 +199,12 @@ class BaseTable(dict):
     def Set(self, key, value, dumper=json.dumps, dumperKwargs={'indent': 2, 'sort_keys': True}):
         value = dumper(value, **dumperKwargs)
         self[key] = value
+        self.Commit()
+
+    def Remove(self, key, value):
+        l = self.Get(key, [])
+        l.remove(value)
+        self.Set(key, l)
 
     def Append(self, key, value):
         '''
@@ -216,7 +223,6 @@ class BaseTable(dict):
         items = self.Get(key, [])
         items.append(value)
         self.Set(key, items)
-        self.Commit()
 
     def SetItem(self, key, subKey, value):
         '''
@@ -235,4 +241,14 @@ class BaseTable(dict):
         items = self.Get(key, {})
         items[subKey] = value
         self.Set(key, items)
-        self.Commit()
+
+    def GetItem(self, key, subkey, default):
+        d = self.Get(key, {})
+        ret = d.get(subkey, default)
+        return ret
+
+    def PopItem(self, key, subkey, default=None):
+        d = self.Get(key, {})
+        ret = d.pop(subkey, default)
+        self.Set(key, d)
+        return ret
